[mutter/wayland] constraints: don't apply fullscreen workarounds for CSD windows



commit 52e2a1226eb08cd46865b0ee554da87a1a7823ca
Author: Giovanni Campagna <gcampagn redhat com>
Date:   Thu Sep 26 10:33:06 2013 +0200

    constraints: don't apply fullscreen workarounds for CSD windows
    
    If you maximize a CSD window on a monitor without struts, it ends
    up taking the whole monitor size, but it doesn't mean that the
    application wants to fullscreen.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=708718

 src/core/constraints.c |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)
---
diff --git a/src/core/constraints.c b/src/core/constraints.c
index 606baea..20a918b 100644
--- a/src/core/constraints.c
+++ b/src/core/constraints.c
@@ -447,12 +447,14 @@ setup_constraint_info (ConstraintInfo      *info,
 
   /* Workaround braindead legacy apps that don't know how to
    * fullscreen themselves properly - don't get fooled by
    * windows which hide their titlebar when maximized; that's
    * not the same as fullscreen, even if there are no struts
    * making the workarea smaller than the monitor.
    */
   if (meta_prefs_get_force_fullscreen() &&
       !window->hide_titlebar_when_maximized &&
+      window->decorated &&
       meta_rectangle_equal (new, &monitor_info->rect) &&
       window->has_fullscreen_func &&
       !window->fullscreen)
@@ -447,12 +447,14 @@ setup_constraint_info (ConstraintInfo      *info,
   /* Workaround braindead legacy apps that don't know how to
    * fullscreen themselves properly - don't get fooled by
-   * windows which hide their titlebar when maximized; that's
-   * not the same as fullscreen, even if there are no struts
-   * making the workarea smaller than the monitor.
+   * windows which hide their titlebar when maximized or which are
+   * client decorated; that's not the same as fullscreen, even
+   * if there are no struts making the workarea smaller than
+   * the monitor.
    */
   if (meta_prefs_get_force_fullscreen() &&


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]